from __future__ import unicode_literals

from django.forms.widgets import TextInput
from django.template.loader import get_template
from django.conf import settings


class JsTreeWidget(TextInput):
    def __init__(self, url, attrs=None):
        super(JsTreeWidget, self).__init__(attrs=attrs)
        self.url = url
        # custom widget if not specified in attrs
        self.attrs.setdefault('readonly', True)
        self.attrs.setdefault('required', True)
        self.attrs.setdefault('max_length', 255)
        self.attrs.setdefault('size', 100)

    class Media:
        css = {
            'all': (
                'jstree/css/jstree/themes/default/style{}.css/'.format('.min' if settings.DEBUG else ''),
            )
        }
        js = (
            'jstree/js/jstree{}.js'.format('.min' if settings.DEBUG else ''),
        )

    def render(self, name, value, attrs=None, renderer=None):
        rendering = super(JsTreeWidget, self).render(name, value, attrs=attrs)
        div_id = "{}-tree".format(name)
        rendering = "{}{}".format(rendering,
                                  get_template("jstree/widgets/jstree.div.html").render(
                                      {'div_id': div_id,
                                       'field_name': name, })
                                  )
        rendering = "{}{}".format(rendering,
                                  get_template("jstree/widgets/jstree.init.js").render(
                                      {'div_id': div_id,
                                       'field_name': name,
                                       'url': self.url})
                                  )
        return rendering



from __future__ import unicode_literals
import os

dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))

with open(os.path.join(dir_path, 'VERSION'), 'r') as file_version:
    __version__ = file_version.read()


from __future__ import unicode_literals
from setuptools import setup, find_packages


from jstree import __version__
with open('LICENSE', 'r') as license_file:
    license = license_file.read()

setup(
    name='django-jstree-widget',
    version=__version__,
    packages=find_packages(),
    author='Jean-Etienne Castagnede',
    author_email='j.e.castagnede@gmail.com',
    license=license,
    description='Customizable widget to serve jstree with django.',
)